/*
  Out of the Box
  This is the code that is run when the user opens the
  box and connects the SSTuino II to power

  Written by Pan Ziyue for FourierIndustries
  Licensed under the Creative Commons 0 (CC0) License and
  released to public domain
  <http://creativecommons.org/publicdomain/zero/1.0/>
 */

#include <SPI.h>
#include <WiFiNINA.h>

const int led[] = {2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13}, d = 100;

#define BRIGHTNESS 32
#define DELAY 30

bool lightbar = true;
unsigned int ledToLight = 2;
unsigned int counter = 0;
bool reverse = false;

void setup()
{
  delay(500);

  if (lightbar)
  {
    for (int i = 0; i < 12; i++)
    {
      pinMode(led[i], OUTPUT);
    }
  }

  // Perform a single cycle through on pure colours
  WiFi.setLEDs(BRIGHTNESS, 0, 0);
  delay(500);
  WiFi.setLEDs(0, BRIGHTNESS, 0);
  delay(500);
  WiFi.setLEDs(0, 0, BRIGHTNESS);
  delay(500);
}

void loop()
{
  unsigned int rgbColour[3];
  // Start off with red.
  rgbColour[0] = BRIGHTNESS;
  rgbColour[1] = 0;
  rgbColour[2] = 0;

  // Choose the colours to increment and decrement.
  for (int decColour = 0; decColour < 3; decColour += 1)
  {
    int incColour = decColour == 2 ? 0 : decColour + 1;

    // cross-fade the two colours.
    for (int i = 0; i < BRIGHTNESS; i += 1)
    {
      rgbColour[decColour] -= 1;
      rgbColour[incColour] += 1;

      setColourRgb(rgbColour[0], rgbColour[1], rgbColour[2]);
      delay(DELAY);

      if (lightbar)
      {
        counter++;
        if (counter >= 3)
        {
          setAllLow();
          if (ledToLight >= 13)
          {
            // reverse the direction
            reverse = true;
          }
          else if (ledToLight <= 2)
          {
            reverse = false;
          }
          digitalWrite(ledToLight, HIGH);
          if (reverse)
          {
            ledToLight--;
          }
          else
          {
            ledToLight++;
          }
          counter = 0;
        }
      }
    }
  }
}

void setColourRgb(unsigned int red, unsigned int green, unsigned int blue)
{
  WiFi.setLEDs(red, green, blue);
}

void setAllLow()
{
  for (int i = 0; i < 12; i++)
  {
    digitalWrite(led[i], LOW);
  }
}
